# The Swarmchestrate Docs

![](img/logo-horizontal.png)

Welcome to the documentation pages for the Swarmchestrate project.
This resource contains information for application owners, capacity
providers and Swarmchestrate developers.

## Key Terms

* **SAT** - a **S**warm **A**pplication **T**emplate is the main
application input to a Swarmchestrate Universe. Application owners author
a SAT, which defines the microservices and resource requirements that make
up an application.

* **CDT** - a **C**apacity **D**escription **T**emplate defines the possible
instance types that are made available by a given capacity, as well as any
quotas that are to be enforced

* **Sardou** - the Swarmchestrate TOSCA library, named after the French
author, Sardou, is the developer toolkit for working with SATs and CDTs.
Sardou provides fsuch eatures as validation, translation and extraction.

## First Steps

* If you are an application owner, visit the [Application Authoring Guide](sat.md).
* If you are a capacity provider, visit the [Capacity Authoring Guide](cdt.md).
* If you are a Swarmchestrate dev, visit the [Sardou library docs](sardou.md).